// Create offscreen document for HTML parsing
async function createOffscreen() {
  if (await chrome.offscreen.hasDocument()) return;
  await chrome.offscreen.createDocument({
    url: 'offscreen.html',
    reasons: ['DOM_PARSER'],
    justification: 'Parse HTML response from prog.co.il'
  });
}

// Listen for installation
chrome.runtime.onInstalled.addListener(async (details) => {
    if (details.reason === 'install') {
        console.log('Extension installed - checking for initial alerts');
        // בדיקה ראשונית של התראות
        await checkForNewAlerts();
    }
});

// Set up alarm to check for notifications periodically
chrome.alarms.create('checkAlerts', {
    periodInMinutes: 1
});

// Listen for alarm
chrome.alarms.onAlarm.addListener((alarm) => {
    if (alarm.name === 'checkAlerts') {
        checkForNewAlerts();
    }
});

// Function to check for new alerts
async function checkForNewAlerts() {
    try {
        await createOffscreen();
        
        const response = await fetch('https://www.prog.co.il/account/alerts-popup', {
            credentials: 'include'
        });
        
        if (!response.ok) {
            throw new Error(`HTTP error! status: ${response.status}`);
        }
        
        const data = await response.text();
        
        // Parse alerts from the response
        const alerts = await parseAlerts(data);
        
        // Get previous alerts count
        const { alerts: previousAlerts = [] } = await chrome.storage.local.get('alerts');
        const isFirstRun = !previousAlerts || previousAlerts.length === 0;
        
        // שמירת ההתראות באחסון המקומי
        await chrome.storage.local.set({ 'alerts': alerts });
        
        // עדכון הבאדג'
        updateBadge(alerts.length);
        
        // Show notification and play sound for new alerts or on first run
        if (alerts.length > previousAlerts.length || (isFirstRun && alerts.length > 0)) {
            // Play notification sound
            await playNotificationSound();
            
            try {
                showNotification(alerts);
            } catch (error) {
                console.error('Error showing notification:', error);
                showNotification(alerts, true);
            }
        }
        
    } catch (error) {
        console.error('Error checking for alerts:', error);
    }
}

// Function to play notification sound
async function playNotificationSound() {
    try {
        console.log('Starting to play notification sound...');
        
        console.log('Creating offscreen document...');
        await createOffscreen();
        
        const soundUrl = chrome.runtime.getURL('sounds/message.wav');
        console.log('Sound URL:', soundUrl);
        
        console.log('Sending message to offscreen page...');
        const response = await chrome.runtime.sendMessage({
            type: 'play-sound',
            target: 'offscreen',
            soundUrl: soundUrl
        });
        
        console.log('Response from offscreen page:', response);
        
        if (response && response.success) {
            console.log('Notification sound played successfully');
        } else {
            console.error('Failed to play notification sound:', response?.error);
        }
    } catch (error) {
        console.error('Error in playNotificationSound:', error);
    }
}

// Function to format alert text
function formatAlertText(text) {
    if (!text) return '';
    
    // מנקה תווים מיותרים
    return text.replace(/^>/, '').trim();
}

// Function to show notification
function showNotification(alerts, skipIcon = false) {
    if (!alerts || alerts.length === 0) return;

    // מקבל את ההתראה האחרונה
    const lastAlert = alerts[0];
    const alertText = lastAlert?.content || '';
    
    if (!alertText) return;

    // מנקה את הטקסט
    const cleanText = formatAlertText(alertText);
    
    // בונה את כותרת ההתראה
    let title = 'התראה חדשה מפרוג';
    if (alerts.length > 1) {
        title = `${alerts.length} התראות חדשות מפרוג`;
    }
    
    // בונה את תוכן ההתראה
    let message = cleanText;
    if (alerts.length > 1) {
        message = `ההתראה האחרונה:\n${cleanText}`;
    }
    
    const notificationOptions = {
        type: 'basic',
        title: title,
        message: message,
        priority: 2,
        requireInteraction: false,
        silent: true
    };

    if (!skipIcon) {
        notificationOptions.iconUrl = chrome.runtime.getURL('icons/icon48.png');
    }

    // יצירת מזהה ייחודי להתראה
    const notificationId = 'prog-alerts-' + Date.now();
    
    chrome.notifications.create(notificationId, notificationOptions, (notificationId) => {
        if (chrome.runtime.lastError) {
            console.error('Error creating notification:', chrome.runtime.lastError);
        }
        
        // סגירה אוטומטית אחרי 7 שניות
        setTimeout(() => {
            chrome.notifications.clear(notificationId);
        }, 7000);
    });
}

// Function to update badge with number of alerts
function updateBadge(alertCount) {
    if (alertCount > 0) {
        chrome.action.setBadgeText({ text: alertCount.toString() });
        chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });
    } else {
        chrome.action.setBadgeText({ text: '' });
    }
}

// Listen for messages from popup
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    console.log('Received message:', request);
    
    if (request.action === 'getAlerts') {
        chrome.storage.local.get('alerts', (result) => {
            console.log('Sending alerts to popup:', result.alerts);
            sendResponse(result.alerts);
        });
    }
    else if (request.action === 'checkAlerts') {
        checkForNewAlerts().then(() => {
            sendResponse({ success: true });
        });
        return true;  // Will respond asynchronously
    }
    else if (request.action === 'markAsRead') {
        // Mark alert as read logic here
        fetch(`https://www.prog.co.il/account/alert-read?alert_id=${request.alertId}`, {
            credentials: 'include'
        }).then(() => {
            chrome.storage.local.get('alerts', (result) => {
                const alerts = result.alerts.filter(alert => alert.id !== request.alertId);
                chrome.storage.local.set({ 'alerts': alerts });
                sendResponse({ success: true });
            });
        });
        return true;  // Will respond asynchronously
    }
});

// Function to parse alerts from HTML
async function parseAlerts(html) {
    // Create offscreen document to parse alerts
    await createOffscreen();
    const response = await chrome.runtime.sendMessage({ 
        action: 'parseHTML',
        html: html,
        target: 'offscreen'
    });
    
    if (!response || !response.alerts) {
        console.error('Failed to parse alerts:', response);
        return [];
    }
    
    return response.alerts;
}

// Initial check for alerts
checkForNewAlerts();
