// Function to update alerts display
function updateAlerts() {
    const alertsContainer = document.getElementById('notifications');
    const countElement = document.getElementById('count');
    const refreshButton = document.getElementById('refresh-button');
    
    if (!alertsContainer || !countElement || !refreshButton) {
        console.error('Could not find required elements');
        return;
    }
    
    // Add spinning animation to refresh button
    refreshButton.classList.add('spinning');
    
    // Get alerts from storage
    chrome.storage.local.get('alerts', (result) => {
        const alerts = result.alerts || [];
        
        // Update count display
        updateCount(alerts.length);
        
        // Update alerts display
        if (alerts.length === 0) {
            alertsContainer.innerHTML = '<div class="no-alerts">אין התראות חדשות</div>';
        } else {
            alertsContainer.innerHTML = '';
            alerts.forEach(alert => {
                const alertElement = createAlertElement(alert);
                
                // הוספת מאזין לקליק על ההתראה
                alertElement.querySelector('a').addEventListener('click', (e) => {
                    e.preventDefault();
                    markAlertAsRead(alert.id);
                    window.open(alert.url, '_blank');
                    startAutoCloseTimer();  // התחל טיימר לסגירה אוטומטית
                });
                
                alertsContainer.appendChild(alertElement);
            });
        }
        
        // Remove spinning animation
        setTimeout(() => {
            refreshButton.classList.remove('spinning');
        }, 500);
    });
}

// Function to format alert text
function formatAlertText(text) {
    // מחלק את הטקסט לחלקים לפי התבנית
    const parts = {
        username: '',
        action: '',
        topic: '',
        rest: ''
    };

    // מוצא את שם המשתמש והפעולה
    const userActionMatch = text.match(/^(.+?)(הגיב\/ה לנושא|שלח\/ה  תודה על ההודעה שלך בנושא:)/);
    if (userActionMatch) {
        parts.username = userActionMatch[1].trim();
        parts.action = userActionMatch[2];

        // מחלק את שאר הטקסט לנושא ושאר המידע
        const remainingText = text.slice(userActionMatch[0].length).trim();
        const topicEndIndex = remainingText.indexOf('. יתכן');
        if (topicEndIndex !== -1) {
            parts.topic = remainingText.slice(0, topicEndIndex);
            parts.rest = remainingText.slice(topicEndIndex);
        } else {
            parts.topic = remainingText;
        }
    }

    return `<b>${parts.username}</b>${parts.action} <b>${parts.topic}</b>${parts.rest}`;
}

// Function to refresh alerts
async function refreshAlerts() {
    const refreshButton = document.getElementById('refresh-button');
    if (refreshButton) {
        refreshButton.classList.add('spinning');
    }
    
    try {
        // Send message to background script to check for new alerts
        await chrome.runtime.sendMessage({ action: 'checkAlerts' });
        
        // Get current alerts from storage
        const { alerts = [] } = await chrome.storage.local.get('alerts');
        
        // Update alerts count
        document.getElementById('count').textContent = alerts.length;

        // Clear existing alerts
        const alertsContainer = document.getElementById('notifications');
        alertsContainer.innerHTML = '';

        // Add alerts to container
        alerts.forEach(alert => {
            const alertElement = createAlertElement(alert);
            
            // הוספת מאזין לקליק על ההתראה
            alertElement.querySelector('a').addEventListener('click', (e) => {
                e.preventDefault();
                markAlertAsRead(alert.id);
                window.open(alert.url, '_blank');
                startAutoCloseTimer();  // התחל טיימר לסגירה אוטומטית
            });
            
            alertsContainer.appendChild(alertElement);
        });

    } catch (error) {
        console.error('Error refreshing alerts:', error);
    } finally {
        if (refreshButton) {
            refreshButton.classList.remove('spinning');
        }
    }
}

// Function to update count display
function updateCount(count) {
    const countElement = document.getElementById('count');
    if (countElement) {
        countElement.textContent = count;
        countElement.style.display = count > 0 ? 'inline-block' : 'none';
        document.title = `התראות מפרוג ${count > 0 ? `(${count})` : ''}`;
    }
}

function createAlertElement(alert) {
    const alertDiv = document.createElement('div');
    alertDiv.className = 'alert';
    alertDiv.setAttribute('data-alert-id', alert.id);

    const link = document.createElement('a');
    link.className = 'alert-link';
    link.href = alert.url;
    link.target = '_blank';

    // פירוק הטקסט לחלקים
    const match = alert.content.match(/^(.+?) (הגיב\/ה לנושא) (.+?)(?:\. (.+))?$/);
    if (match) {
        const [_, username, action, topic, rest] = match;
        
        const alertContent = document.createElement('div');
        alertContent.className = 'alert-content';

        // שם המשתמש - שחור ודגוש
        const usernameSpan = document.createElement('span');
        usernameSpan.style.color = '#000';
        usernameSpan.style.fontWeight = 'bold';
        usernameSpan.textContent = username;
        
        // טקסט "הגיב/ה לנושא" - אפור רגיל
        const actionSpan = document.createElement('span');
        actionSpan.style.color = '#666';
        actionSpan.textContent = ' ' + action + ' ';
        
        // שם הנושא - שחור ודגוש
        const topicSpan = document.createElement('span');
        topicSpan.style.color = '#000';
        topicSpan.style.fontWeight = 'bold';
        topicSpan.textContent = topic;
        
        // שאר הטקסט - אפור רגיל
        const restSpan = document.createElement('span');
        restSpan.style.color = '#666';
        restSpan.textContent = rest ? '. ' + rest : '';

        // הוספת כל החלקים
        alertContent.appendChild(usernameSpan);
        alertContent.appendChild(actionSpan);
        alertContent.appendChild(topicSpan);
        alertContent.appendChild(restSpan);

        link.appendChild(alertContent);
    } else {
        // אם אין התאמה, נציג את הטקסט המקורי
        const alertContent = document.createElement('div');
        alertContent.className = 'alert-content';
        alertContent.innerHTML = formatAlertText(alert.content);
        link.appendChild(alertContent);
    }

    alertDiv.appendChild(link);
    return alertDiv;
}

// Function to close popup window
function closePopup() {
    window.close();
}

// Function to start auto-close timer
function startAutoCloseTimer() {
    console.log('Starting auto-close timer');
    setTimeout(closePopup, 7000);  // 7 seconds
}

// Listen for messages from background script
window.addEventListener('message', (event) => {
    if (event.data.type === 'alertsUpdated') {
        updateCount(event.data.alerts.length);
    }
});

// Initialize alerts display when popup opens
document.addEventListener('DOMContentLoaded', () => {
    const refreshButton = document.getElementById('refresh-button');
    if (refreshButton) {
        refreshButton.addEventListener('click', refreshAlerts);
    }
    updateAlerts();
});

function getTimeAgo(date) {
    const now = new Date();
    const seconds = Math.floor((now - date) / 1000);
    const minutes = Math.floor(seconds / 60);
    const hours = Math.floor(minutes / 60);
    const days = Math.floor(hours / 24);

    if (days > 0) {
        return `לפני ${days} ${days === 1 ? 'יום' : 'ימים'}`;
    } else if (hours > 0) {
        return `לפני ${hours} ${hours === 1 ? 'שעה' : 'שעות'}`;
    } else if (minutes > 0) {
        return `לפני ${minutes} ${minutes === 1 ? 'דקה' : 'דקות'}`;
    } else {
        return 'לפני פחות מדקה';
    }
}

function markAlertAsRead(alertId) {
    chrome.storage.local.get(['alerts', 'seenAlerts'], (result) => {
        const currentAlerts = result.alerts || [];
        const seenAlerts = result.seenAlerts || [];
        
        // Remove this alert from the list
        const newAlerts = currentAlerts.filter(a => a.id !== alertId);
        
        // Update storage
        chrome.storage.local.set({
            'alerts': newAlerts,
            'seenAlerts': [...seenAlerts, alertId]
        }, () => {
            // עדכון מספר ההתראות
            const countElement = document.getElementById('count');
            if (countElement) {
                countElement.textContent = newAlerts.length;
                countElement.style.display = newAlerts.length > 0 ? 'inline-block' : 'none';
            }
            
            // עדכון הכותרת של החלון
            document.title = `התראות מפרוג ${newAlerts.length > 0 ? `(${newAlerts.length})` : ''}`;
            
            // Remove the alert element from the popup
            const alertElement = document.querySelector(`[data-alert-id="${alertId}"]`);
            if (alertElement) {
                alertElement.style.opacity = '0';
                alertElement.style.transform = 'translateX(100%)';
                setTimeout(() => {
                    alertElement.remove();
                    
                    // If no more alerts, show the "no alerts" message
                    if (newAlerts.length === 0) {
                        const alertsContainer = document.getElementById('notifications');
                        if (alertsContainer) {
                            alertsContainer.innerHTML = '<div class="no-alerts">אין התראות חדשות</div>';
                        }
                    }
                }, 300);
            }
        });
    });
}

function showNoAlerts() {
  const notificationsDiv = document.getElementById('notifications');
  const noAlertsDiv = document.createElement('div');
  noAlertsDiv.className = 'no-alerts';
  noAlertsDiv.textContent = 'אין התראות חדשות';
  notificationsDiv.appendChild(noAlertsDiv);
}
